==> crm-commom-vo-1.0.0.release.jar: com/biz/crm/nebular/mdm/CrmExtEditVo.java <==
package com.biz.crm.nebular.mdm;

import com.bizunited.platform.common.vo.FormInstanceUuidVo;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description: 拓展字段entity,用于需要拓展字段的实体
 * @Author: zhangyuzhu
 * @Date: 2020/8/19 10:08
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class CrmExtEditVo  extends FormInstanceUuidVo {

    private String ext1 = StringUtils.EMPTY;

    private String ext2 = StringUtils.EMPTY;

    private String ext3 = StringUtils.EMPTY;

    private String ext4 = StringUtils.EMPTY;

    private String ext5 = StringUtils.EMPTY;

    private String ext6 = StringUtils.EMPTY;

    private String ext7 = StringUtils.EMPTY;

    private String ext8 = StringUtils.EMPTY;

    private String ext9 = StringUtils.EMPTY;

    private String ext10 = StringUtils.EMPTY;

    private String ext11 = StringUtils.EMPTY;

    private String ext12 = StringUtils.EMPTY;

    private String ext13 = StringUtils.EMPTY;

    private String ext14 = StringUtils.EMPTY;

    private String ext15 = StringUtils.EMPTY;

    private String ext16 = StringUtils.EMPTY;

    private String ext17 = StringUtils.EMPTY;

    private String ext18 = StringUtils.EMPTY;

    private String ext19 = StringUtils.EMPTY;

    private String ext20 = StringUtils.EMPTY;

    private String ext21 = StringUtils.EMPTY;

    private String ext22 = StringUtils.EMPTY;

    private String ext23 = StringUtils.EMPTY;

    private String ext24 = StringUtils.EMPTY;

    private String ext25 = StringUtils.EMPTY;

    private String ext26 = StringUtils.EMPTY;

    private String ext27 = StringUtils.EMPTY;

    private String ext28 = StringUtils.EMPTY;

    private String ext29 = StringUtils.EMPTY;

    private String ext30 = StringUtils.EMPTY;

    private String ext31 = StringUtils.EMPTY;

    private String ext32 = StringUtils.EMPTY;

    private String ext33 = StringUtils.EMPTY;

    private String ext34 = StringUtils.EMPTY;

    private String ext35 = StringUtils.EMPTY;

    private String ext36 = StringUtils.EMPTY;

    private String ext37 = StringUtils.EMPTY;

    private String ext38 = StringUtils.EMPTY;

    private String ext39 = StringUtils.EMPTY;

    private String ext40 = StringUtils.EMPTY;

    private String ext41 = StringUtils.EMPTY;

    private String ext42 = StringUtils.EMPTY;

    private String ext43 = StringUtils.EMPTY;

    private String ext44 = StringUtils.EMPTY;

    private String ext45 = StringUtils.EMPTY;

    private String ext46 = StringUtils.EMPTY;

    private String ext47 = StringUtils.EMPTY;

    private String ext48 = StringUtils.EMPTY;

    private String ext49 = StringUtils.EMPTY;

    private String ext50 = StringUtils.EMPTY;

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public String getExt6() {
        return ext6;
    }

    public void setExt6(String ext6) {
        this.ext6 = ext6;
    }

    public String getExt7() {
        return ext7;
    }

    public void setExt7(String ext7) {
        this.ext7 = ext7;
    }

    public String getExt8() {
        return ext8;
    }

    public void setExt8(String ext8) {
        this.ext8 = ext8;
    }

    public String getExt9() {
        return ext9;
    }

    public void setExt9(String ext9) {
        this.ext9 = ext9;
    }

    public String getExt10() {
        return ext10;
    }

    public void setExt10(String ext10) {
        this.ext10 = ext10;
    }

    public String getExt11() {
        return ext11;
    }

    public void setExt11(String ext11) {
        this.ext11 = ext11;
    }

    public String getExt12() {
        return ext12;
    }

    public void setExt12(String ext12) {
        this.ext12 = ext12;
    }

    public String getExt13() {
        return ext13;
    }

    public void setExt13(String ext13) {
        this.ext13 = ext13;
    }

    public String getExt14() {
        return ext14;
    }

    public void setExt14(String ext14) {
        this.ext14 = ext14;
    }

    public String getExt15() {
        return ext15;
    }

    public void setExt15(String ext15) {
        this.ext15 = ext15;
    }

    public String getExt16() {
        return ext16;
    }

    public void setExt16(String ext16) {
        this.ext16 = ext16;
    }

    public String getExt17() {
        return ext17;
    }

    public void setExt17(String ext17) {
        this.ext17 = ext17;
    }

    public String getExt18() {
        return ext18;
    }

    public void setExt18(String ext18) {
        this.ext18 = ext18;
    }

    public String getExt19() {
        return ext19;
    }

    public void setExt19(String ext19) {
        this.ext19 = ext19;
    }

    public String getExt20() {
        return ext20;
    }

    public void setExt20(String ext20) {
        this.ext20 = ext20;
    }

    public String getExt21() {
        return ext21;
    }

    public void setExt21(String ext21) {
        this.ext21 = ext21;
    }

    public String getExt22() {
        return ext22;
    }

    public void setExt22(String ext22) {
        this.ext22 = ext22;
    }

    public String getExt23() {
        return ext23;
    }

    public void setExt23(String ext23) {
        this.ext23 = ext23;
    }

    public String getExt24() {
        return ext24;
    }

    public void setExt24(String ext24) {
        this.ext24 = ext24;
    }

    public String getExt25() {
        return ext25;
    }

    public void setExt25(String ext25) {
        this.ext25 = ext25;
    }

    public String getExt26() {
        return ext26;
    }

    public void setExt26(String ext26) {
        this.ext26 = ext26;
    }

    public String getExt27() {
        return ext27;
    }

    public void setExt27(String ext27) {
        this.ext27 = ext27;
    }

    public String getExt28() {
        return ext28;
    }

    public void setExt28(String ext28) {
        this.ext28 = ext28;
    }

    public String getExt29() {
        return ext29;
    }

    public void setExt29(String ext29) {
        this.ext29 = ext29;
    }

    public String getExt30() {
        return ext30;
    }

    public void setExt30(String ext30) {
        this.ext30 = ext30;
    }

    public String getExt31() {
        return ext31;
    }

    public void setExt31(String ext31) {
        this.ext31 = ext31;
    }

    public String getExt32() {
        return ext32;
    }

    public void setExt32(String ext32) {
        this.ext32 = ext32;
    }

    public String getExt33() {
        return ext33;
    }

    public void setExt33(String ext33) {
        this.ext33 = ext33;
    }

    public String getExt34() {
        return ext34;
    }

    public void setExt34(String ext34) {
        this.ext34 = ext34;
    }

    public String getExt35() {
        return ext35;
    }

    public void setExt35(String ext35) {
        this.ext35 = ext35;
    }

    public String getExt36() {
        return ext36;
    }

    public void setExt36(String ext36) {
        this.ext36 = ext36;
    }

    public String getExt37() {
        return ext37;
    }

    public void setExt37(String ext37) {
        this.ext37 = ext37;
    }

    public String getExt38() {
        return ext38;
    }

    public void setExt38(String ext38) {
        this.ext38 = ext38;
    }

    public String getExt39() {
        return ext39;
    }

    public void setExt39(String ext39) {
        this.ext39 = ext39;
    }

    public String getExt40() {
        return ext40;
    }

    public void setExt40(String ext40) {
        this.ext40 = ext40;
    }

    public String getExt41() {
        return ext41;
    }

    public void setExt41(String ext41) {
        this.ext41 = ext41;
    }

    public String getExt42() {
        return ext42;
    }

    public void setExt42(String ext42) {
        this.ext42 = ext42;
    }

    public String getExt43() {
        return ext43;
    }

    public void setExt43(String ext43) {
        this.ext43 = ext43;
    }

    public String getExt44() {
        return ext44;
    }

    public void setExt44(String ext44) {
        this.ext44 = ext44;
    }

    public String getExt45() {
        return ext45;
    }

    public void setExt45(String ext45) {
        this.ext45 = ext45;
    }

    public String getExt46() {
        return ext46;
    }

    public void setExt46(String ext46) {
        this.ext46 = ext46;
    }

    public String getExt47() {
        return ext47;
    }

    public void setExt47(String ext47) {
        this.ext47 = ext47;
    }

    public String getExt48() {
        return ext48;
    }

    public void setExt48(String ext48) {
        this.ext48 = ext48;
    }

    public String getExt49() {
        return ext49;
    }

    public void setExt49(String ext49) {
        this.ext49 = ext49;
    }

    public String getExt50() {
        return ext50;
    }

    public void setExt50(String ext50) {
        this.ext50 = ext50;
    }
}

==> crm-commom-vo-1.1.1.release.jar: com/biz/crm/nebular/mdm/CrmExtEditVo.java <==
package com.biz.crm.nebular.mdm;

import com.bizunited.platform.common.vo.FormInstanceUuidVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.apache.commons.lang3.StringUtils;

/**
 * @Description: 拓展字段entity,用于需要拓展字段的实体
 * @Author: zhangyuzhu
 * @Date: 2020/8/19 10:08
 **/
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class CrmExtEditVo  extends FormInstanceUuidVo {

    @SaturnColumn(description = "ext1")
    private String ext1 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext2")
    private String ext2 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext3")
    private String ext3 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext4")
    private String ext4 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext5")
    private String ext5 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext6")
    private String ext6 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext7")
    private String ext7 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext8")
    private String ext8 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext9")
    private String ext9 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext10")
    private String ext10 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext11")
    private String ext11 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext12")
    private String ext12 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext13")
    private String ext13 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext14")
    private String ext14 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext15")
    private String ext15 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext16")
    private String ext16 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext17")
    private String ext17 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext18")
    private String ext18 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext19")
    private String ext19 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext20")
    private String ext20 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext21")
    private String ext21 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext22")
    private String ext22 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext23")
    private String ext23 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext24")
    private String ext24 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext25")
    private String ext25 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext26")
    private String ext26 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext27")
    private String ext27 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext28")
    private String ext28 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext29")
    private String ext29 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext30")
    private String ext30 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext31")
    private String ext31 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext32")
    private String ext32 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext33")
    private String ext33 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext34")
    private String ext34 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext35")
    private String ext35 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext36")
    private String ext36 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext37")
    private String ext37 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext38")
    private String ext38 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext39")
    private String ext39 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext40")
    private String ext40 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext41")
    private String ext41 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext42")
    private String ext42 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext43")
    private String ext43 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext44")
    private String ext44 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext45")
    private String ext45 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext46")
    private String ext46 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext47")
    private String ext47 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext48")
    private String ext48 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext49")
    private String ext49 = StringUtils.EMPTY;

    @SaturnColumn(description = "ext50")
    private String ext50 = StringUtils.EMPTY;

    public String getExt1() {
        return ext1;
    }

    public void setExt1(String ext1) {
        this.ext1 = ext1;
    }

    public String getExt2() {
        return ext2;
    }

    public void setExt2(String ext2) {
        this.ext2 = ext2;
    }

    public String getExt3() {
        return ext3;
    }

    public void setExt3(String ext3) {
        this.ext3 = ext3;
    }

    public String getExt4() {
        return ext4;
    }

    public void setExt4(String ext4) {
        this.ext4 = ext4;
    }

    public String getExt5() {
        return ext5;
    }

    public void setExt5(String ext5) {
        this.ext5 = ext5;
    }

    public String getExt6() {
        return ext6;
    }

    public void setExt6(String ext6) {
        this.ext6 = ext6;
    }

    public String getExt7() {
        return ext7;
    }

    public void setExt7(String ext7) {
        this.ext7 = ext7;
    }

    public String getExt8() {
        return ext8;
    }

    public void setExt8(String ext8) {
        this.ext8 = ext8;
    }

    public String getExt9() {
        return ext9;
    }

    public void setExt9(String ext9) {
        this.ext9 = ext9;
    }

    public String getExt10() {
        return ext10;
    }

    public void setExt10(String ext10) {
        this.ext10 = ext10;
    }

    public String getExt11() {
        return ext11;
    }

    public void setExt11(String ext11) {
        this.ext11 = ext11;
    }

    public String getExt12() {
        return ext12;
    }

    public void setExt12(String ext12) {
        this.ext12 = ext12;
    }

    public String getExt13() {
        return ext13;
    }

    public void setExt13(String ext13) {
        this.ext13 = ext13;
    }

    public String getExt14() {
        return ext14;
    }

    public void setExt14(String ext14) {
        this.ext14 = ext14;
    }

    public String getExt15() {
        return ext15;
    }

    public void setExt15(String ext15) {
        this.ext15 = ext15;
    }

    public String getExt16() {
        return ext16;
    }

    public void setExt16(String ext16) {
        this.ext16 = ext16;
    }

    public String getExt17() {
        return ext17;
    }

    public void setExt17(String ext17) {
        this.ext17 = ext17;
    }

    public String getExt18() {
        return ext18;
    }

    public void setExt18(String ext18) {
        this.ext18 = ext18;
    }

    public String getExt19() {
        return ext19;
    }

    public void setExt19(String ext19) {
        this.ext19 = ext19;
    }

    public String getExt20() {
        return ext20;
    }

    public void setExt20(String ext20) {
        this.ext20 = ext20;
    }

    public String getExt21() {
        return ext21;
    }

    public void setExt21(String ext21) {
        this.ext21 = ext21;
    }

    public String getExt22() {
        return ext22;
    }

    public void setExt22(String ext22) {
        this.ext22 = ext22;
    }

    public String getExt23() {
        return ext23;
    }

    public void setExt23(String ext23) {
        this.ext23 = ext23;
    }

    public String getExt24() {
        return ext24;
    }

    public void setExt24(String ext24) {
        this.ext24 = ext24;
    }

    public String getExt25() {
        return ext25;
    }

    public void setExt25(String ext25) {
        this.ext25 = ext25;
    }

    public String getExt26() {
        return ext26;
    }

    public void setExt26(String ext26) {
        this.ext26 = ext26;
    }

    public String getExt27() {
        return ext27;
    }

    public void setExt27(String ext27) {
        this.ext27 = ext27;
    }

    public String getExt28() {
        return ext28;
    }

    public void setExt28(String ext28) {
        this.ext28 = ext28;
    }

    public String getExt29() {
        return ext29;
    }

    public void setExt29(String ext29) {
        this.ext29 = ext29;
    }

    public String getExt30() {
        return ext30;
    }

    public void setExt30(String ext30) {
        this.ext30 = ext30;
    }

    public String getExt31() {
        return ext31;
    }

    public void setExt31(String ext31) {
        this.ext31 = ext31;
    }

    public String getExt32() {
        return ext32;
    }

    public void setExt32(String ext32) {
        this.ext32 = ext32;
    }

    public String getExt33() {
        return ext33;
    }

    public void setExt33(String ext33) {
        this.ext33 = ext33;
    }

    public String getExt34() {
        return ext34;
    }

    public void setExt34(String ext34) {
        this.ext34 = ext34;
    }

    public String getExt35() {
        return ext35;
    }

    public void setExt35(String ext35) {
        this.ext35 = ext35;
    }

    public String getExt36() {
        return ext36;
    }

    public void setExt36(String ext36) {
        this.ext36 = ext36;
    }

    public String getExt37() {
        return ext37;
    }

    public void setExt37(String ext37) {
        this.ext37 = ext37;
    }

    public String getExt38() {
        return ext38;
    }

    public void setExt38(String ext38) {
        this.ext38 = ext38;
    }

    public String getExt39() {
        return ext39;
    }

    public void setExt39(String ext39) {
        this.ext39 = ext39;
    }

    public String getExt40() {
        return ext40;
    }

    public void setExt40(String ext40) {
        this.ext40 = ext40;
    }

    public String getExt41() {
        return ext41;
    }

    public void setExt41(String ext41) {
        this.ext41 = ext41;
    }

    public String getExt42() {
        return ext42;
    }

    public void setExt42(String ext42) {
        this.ext42 = ext42;
    }

    public String getExt43() {
        return ext43;
    }

    public void setExt43(String ext43) {
        this.ext43 = ext43;
    }

    public String getExt44() {
        return ext44;
    }

    public void setExt44(String ext44) {
        this.ext44 = ext44;
    }

    public String getExt45() {
        return ext45;
    }

    public void setExt45(String ext45) {
        this.ext45 = ext45;
    }

    public String getExt46() {
        return ext46;
    }

    public void setExt46(String ext46) {
        this.ext46 = ext46;
    }

    public String getExt47() {
        return ext47;
    }

    public void setExt47(String ext47) {
        this.ext47 = ext47;
    }

    public String getExt48() {
        return ext48;
    }

    public void setExt48(String ext48) {
        this.ext48 = ext48;
    }

    public String getExt49() {
        return ext49;
    }

    public void setExt49(String ext49) {
        this.ext49 = ext49;
    }

    public String getExt50() {
        return ext50;
    }

    public void setExt50(String ext50) {
        this.ext50 = ext50;
    }
}
